@@ -5,12 +5,27 @@ from tkinter import BooleanVar, IntVar, StringVar # _setVariable()
 class SmartWidget:
    __FONT = None
    
-   def __init__(self, master = None, **kw):
+   def __init__(self, master, **kw):
+      self._namePrefix = kw.pop("namePrefix")
+      self._parentContainer = master
+      self._smartWidgetConfig = kw.pop("config")
       self._smartWidgetGrid = kw.pop("grid")
+      self._smartWidgetName = kw.pop("name", None)
       
       # Can be reset in children.
       self._smartWidgetStyle = StaticUtils.mergeJson(*map(lambda styleName: SmartWidget._STYLE_INSTANCE.configure(styleName) or dict(), [self.__class__.STYLE, kw.get("style", "")]), True)
       
+      if hasattr(self._parentContainer, "_topLevelContainer"):
+         self._topLevelContainer = self._parentContainer._topLevelContainer
+      
+      if self._smartWidgetName:
+         result = self._topLevelContainer.getSmartWidget(*self._namePrefix)
+         
+         if isinstance(result, SmartWidget):
+            result = result._baseContainerNamedChildren
+         
+         result[self._smartWidgetName] = self
+      
       for d in (self._smartWidgetGrid, self._smartWidgetStyle):
          for key, value in d.items():
             if key in ("padx", "pady", "childPadx", "childPady"):
@@ -23,14 +38,12 @@ class SmartWidget:
       
       self.__columns = kw.pop("columns", 1)
       self.__rows = kw.pop("rows", 1)
-      self.__smartWidgetName = kw.pop("name", None)
       self.__value = kw.pop("value", None)
       
-      parentBuffer = kw.pop("parentBuffer")
-      parentBufferIndex = kw.pop("parentBufferIndex")
+      if self.__value:
+         self.__defaultValue = self.__value.get()
       
-      if kw.pop("hasValueBuffer", False):
-         self._smartWidgetValueBuffer = StaticUtils.getOrSetIfAbsent(parentBuffer, parentBufferIndex, [])
+      self.__processValueDomains(kw)
       
       if self.__class__._TKINTER_BASE:
          from tkinter.ttk import Widget
@@ -49,6 +62,10 @@ class SmartWidget:
    def grid(self, **kw):
       self.__class__._TKINTER_BASE.grid(self, **StaticUtils.mergeJson(kw, self._smartWidgetGrid, True))
    
+   def reloadValue(self):
+      if len(self.__valueDomains):
+         self.__loadValue()
+   
    @property
    def column(self):
       return self._smartWidgetGrid["column"]
@@ -57,10 +74,6 @@ class SmartWidget:
    def columns(self):
       return self.__columns
    
-   @property
-   def hasValueBuffer(self):
-      return hasattr(self, "_smartWidgetValueBuffer")
-   
    @property
    def row(self):
       return self._smartWidgetGrid["row"]
@@ -69,14 +82,51 @@ class SmartWidget:
    def rows(self):
       return self.__rows
    
-   @property
-   def smartWidgetName(self):
-      return self.__smartWidgetName
+   def _getValueStorage(self):
+      if not self._smartWidgetName:
+         raise ValueError("Can't serialize nameless widgets")
+      
+      storage = self._smartWidgetConfig
+      
+      for keys in (("values", ""), *self.__valueDomains):
+         for k in keys:
+            storage = StaticUtils.setIfAbsentAndGet(storage, k, dict())
+      
+      for domain in self.__valueDomains:
+         storage = StaticUtils.setIfAbsentAndGet(storage, self._topLevelContainer.getSmartWidget(*domain).getValue(), dict())
+      
+      for name in (*self._namePrefix, self._smartWidgetName):
+         storage = StaticUtils.setIfAbsentAndGet(storage, name, dict())
+      
+      return storage
    
    def _initValueAndTraceAdd(self):
-      self.__value.set(StaticUtils.getOrSetIfAbsent(self._smartWidgetValueBuffer, 0, self.__value.get()))
+      self.__loadValue()
+      
+      def _set(*_):
+         self._getValueStorage()[""] = self.__value.get()
+      
+      self.__value.trace_add("write", _set)
+   
+   def __loadValue(self):
+      self.__value.set(StaticUtils.setIfAbsentAndGet(self._getValueStorage(), "", self.__defaultValue))
+   
+   def __processValueDomains(self, kw):
+      domainPresent = "valueDomain" in kw
+      domainsPresent = "valueDomains" in kw
+      present = (domainPresent, domainsPresent)
+      
+      if all(present):
+         raise ValueError(f"Only one of {present} can be present")
+      
+      self.__valueDomains = [kw.pop("valueDomain")] if domainPresent else kw.pop("valueDomains", [])
+      
+      for i in range(len(self.__valueDomains)):
+         if isinstance(self.__valueDomains[i], str) and len(self.__valueDomains[i]):
+            self.__valueDomains[i] = self.__valueDomains[i].split(".")
          
-      self.__value.trace_add("write", lambda *_: StaticUtils.setSafely(self._smartWidgetValueBuffer, 0, self.__value.get()))
+         elif not isinstance(self.__valueDomains[i], list):
+            raise ValueError()
    
    @staticmethod
    def setFont(font):
@@ -88,7 +138,7 @@ class SmartWidget:
          kw["font"] = SmartWidget.__FONT
    
    @staticmethod
-   def _setVariable(kw, defaultTypeName, defaultValueKey = "value", setHasValueBuffer = True, variableKey = None):
+   def _setVariable(kw, defaultTypeName, defaultValueKey = "value", variableKey = None):
       value = eval(f"{kw.pop('valueType', defaultTypeName)}()")
       value.set(kw.get(defaultValueKey, value.get()))
       
@@ -96,6 +146,3 @@ class SmartWidget:
       
       if variableKey:
          kw[variableKey] = value
-      
-      if setHasValueBuffer:
-         kw["hasValueBuffer"] = True
